Project::OSiRiON - Git repositories
Project::OSiRiON
News . About . Screenshots . Downloads . Forum . Wiki . Tracker . Git
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorStijn Buys <ingar@osirion.org>2010-10-25 13:43:11 +0000
committerStijn Buys <ingar@osirion.org>2010-10-25 13:43:11 +0000
commit5189168482f32d8aac630cde27fc0999e70ed57b (patch)
treed96dc388274ff13d594264ed5eeb2f9cce79370d /src/game/base/ship.h
parent787002ec11bf41bba01b899c53a38830768fc260 (diff)
renamed ship torque_force to turn_force, added ship roll_force
Diffstat (limited to 'src/game/base/ship.h')
-rw-r--r--src/game/base/ship.h24
1 files changed, 17 insertions, 7 deletions
diff --git a/src/game/base/ship.h b/src/game/base/ship.h
index 971cb95..9da45f4 100644
--- a/src/game/base/ship.h
+++ b/src/game/base/ship.h
@@ -43,9 +43,14 @@ public:
return ship_strafe_force;
}
- /// torque force
- inline const float torque_force() const {
- return ship_torque_force;
+ /// turn force
+ inline const float turn_force() const {
+ return ship_turn_force;
+ }
+
+ /// roll force
+ inline const float roll_force() const {
+ return ship_roll_force;
}
/// physices frame
@@ -78,11 +83,15 @@ public:
ship_strafe_force = strafe;
}
- /// set torque force
- inline void set_torque_force(const float torque) {
- ship_torque_force = torque;
+ /// set turn force
+ inline void set_turn_force(const float turn) {
+ ship_turn_force = turn;
}
+ /// set roll force
+ inline void set_roll_force(const float roll) {
+ ship_roll_force = roll;
+ }
/// Initiate jump, departing from a jump point
void initiate_jump(JumpPoint *depart);
@@ -121,7 +130,8 @@ private:
float ship_impulse_force;
float ship_thrust_force;
float ship_strafe_force;
- float ship_torque_force;
+ float ship_turn_force;
+ float ship_roll_force;
};
}